@@ -123,7 +123,7 @@ class FastParser:
         html_urls = []
         pdf_urls = []
         yt_urls = []
-        for url in tqdm(urls, desc="processing urls", unit='url'):
+        for url in urls:
             url = self._arxiv_url_fix(url)
             if '/pdf' in url or url.lower().endswith('.pdf'):
                 pdf_urls.append(url)
@@ -210,7 +210,8 @@ class FastParser:
 
 
 def parse(urls: list | str, allow_pdf_extraction=True,
-          allow_youtube_urls_extraction=False, arxiv_html_flag=False, llm=True) -> List[FastParserResult] | FastParserResult:
+          allow_youtube_urls_extraction=False, arxiv_html_flag=False, llm=False) -> List[FastParserResult] | FastParserResult:
+    """takes urls and parse and returns pydantic model of Response(url:str, content:str|None)"""
     parser = FastParser(extract_pdf=allow_pdf_extraction,
                        allow_youtube_urls_extraction=allow_youtube_urls_extraction,
                        arxiv_html_flag=arxiv_html_flag,
@@ -219,7 +220,7 @@ def parse(urls: list | str, allow_pdf_extraction=True,
 
 
 async def aparse(urls: list | str, allow_pdf_extraction=True,
-                 allow_youtube_urls_extraction=False, arxiv_html_flag=False, llm=True) -> List[FastParserResult] | FastParserResult:
+                 allow_youtube_urls_extraction=False, arxiv_html_flag=False, llm=False) -> List[FastParserResult] | FastParserResult:
     parser = FastParser(extract_pdf=allow_pdf_extraction,
                        allow_youtube_urls_extraction=allow_youtube_urls_extraction,
                        arxiv_html_flag=arxiv_html_flag,
